@@ -1,15 +1,22 @@
 import PySimpleGUI as sg
 
 from ArbMasterPy.debug_wrapper import debug_basic
-
-throttle_rate = 1.2 #to control rate of requests to server so we dont get throttled
-
 import xlwings as xw
-api_key = xw.apps.active.books.active.sheets["API"].range("A1").value
+
+throttle_rate = float(xw.apps.active.books.active.sheets["API"].range("B4").value) #to control rate of requests to server so we dont get throttled
+num_results_shown = int(xw.apps.active.books.active.sheets["API"].range("B2").value)
+too_good_to_be_true = float(xw.apps.active.books.active.sheets["API"].range("B3").value)
+search_param = xw.apps.active.books.active.sheets["API"].range("B5").value # search_param should be "" to use google search, and "shop" to use shopping
+
+api_key = xw.apps.active.books.active.sheets["API"].range("B1").value
 
 import pkg_resources
 html_save_loc = pkg_resources.resource_filename('ArbMasterPy', 'data/arbitrage_results_html.html')
 
+def asin_element_to_amazon_links(asin_element):
+    #given the asin element, extracts the link to the amazon page
+    return asin_element.find_all("a", {"class":"amazon-link btn btn-xs btn-primary"})[0]["href"]
+
 import os
 def newest(path):
     #from SO. Returns the newest file in a durectory
@@ -53,61 +60,87 @@ def get_products_and_product_names_and_names_prices(source_html_code):
 
     names_prices = [extract_name_and_max_price(asin_element) for asin_element in asin_elements]
 
+    names_to_amz_link = dict(zip([name for name,price in names_prices], [asin_element_to_amazon_links(element) for element in asin_elements]))
 
-    return products, product_names, names_prices
+
+    return products, product_names, names_prices, names_to_amz_link
 
 import re
-def get_price(input):
-    return float(re.search("[0-9]+[.][0-9]+", input).group())
+def get_price(x):
+    return float(re.search("[0-9]+[.][0-9]+", x).group())
 
-def search_shopping(search_q):
-    from serpapi import GoogleSearch
-
-    params = {
-        "engine": "google",
-        "q": search_q,
-        "location":"United Kingdom",
-        "gl": "uk",
-        "tbm": "shop",
-        "api_key": "ec63b5d769ebfe574934ac3816f218131cf92ccb461375aee6bc5926569f9933",
-    }
-
-    search = GoogleSearch(params)
-    results = search.get_dict()
-    
-    try:
-        source_and_price_and_link = [(result["source"], result["extracted_price"], result["link"]) for result in results["shopping_results"]]
-        source_and_price_and_link.sort(key=lambda x:x[1])
-        source_and_price = [(x[0],x[1]) for x in source_and_price_and_link]
-    except:
-        return None
-    
-    return results, source_and_price_and_link, source_and_price
-
-def search_shopping(search_q):
+import difflib
+def search_shopping(search_q, tbm_param="shop"):
     from serpapi import GoogleSearch
     import os 
+    
+    api_key = "ec63b5d769ebfe574934ac3816f218131cf92ccb461375aee6bc5926569f9933"
+    
+    if tbm_param == "shop":
+    
+        params = {
+            "engine": "google",
+            "q": search_q,
+            "location":"United Kingdom",
+            "gl": "uk",
+            "tbm": "shop",
+            "api_key": api_key,
+        }
 
-    params = {
-        "engine": "google",
-        "q": search_q,
-        "location":"United Kingdom",
-        "gl": "uk",
-        "tbm": "shop",
-        "api_key": api_key,
-    }
-    
-    search = GoogleSearch(params)
-    results = search.get_dict()
-    
-    try:
-        source_and_price_and_link_and_title = [(result["source"], result["extracted_price"], result["link"], result["title"]) for result in results["shopping_results"]]
-        source_and_price_and_link_and_title.sort(key=lambda x:x[1])
-        source_and_price = [(x[0],x[1]) for x in source_and_price_and_link_and_title]
-    except Exception as e:
-        print(e)
-        print(results)
-        return None
+        print("INITIALIZING SEARCH")    
+
+        search = GoogleSearch(params)
+        results = search.get_dict()
+
+        try:
+            source_and_price_and_link_and_title = [(result["source"], result["extracted_price"], result["link"], result["title"]) for result in results["shopping_results"]]
+            source_and_price_and_link_and_title.sort(key=lambda x:1-difflib.SequenceMatcher(None,x[3], search_q).ratio())
+            source_and_price = [(x[0],x[1]) for x in source_and_price_and_link_and_title]
+        except Exception as e:
+            print(e)
+            print(results)
+            return None
+        
+    elif tbm_param == "":
+        params = {
+            "engine": "google",
+            "q": search_q,
+            "location":"United Kingdom",
+            "gl": "uk",
+            "api_key": api_key,
+        }
+
+        print("INITIALIZING SEARCH")    
+
+        search = GoogleSearch(params)
+        results = search.get_dict()
+        try:
+            organic_search = results["organic_results"]
+            source_and_price_and_link_and_title = []
+            for result in organic_search:
+                try:
+                    #this is bad form
+                    price = result['rich_snippet']['top']['detected_extensions']['price']
+                    link = result["link"]
+                    title = result['title']
+                    source = ""
+                    source_and_price_and_link_and_title.append((source,price,link,title))                                                             
+                except KeyError:
+                    pass
+            source_and_price_and_link_and_title.sort(key=lambda x:1-difflib.SequenceMatcher(None,x[3], search_q).ratio())
+            source_and_price = [(x[0],x[1]) for x in source_and_price_and_link_and_title]
+        except Exception as e:
+            print(e)
+            print(results)
+            return None
+
+        
+    else:
+        import PySimpleGUI as sg
+        import sys
+        sg.popup("did not recognise tbm param value")
+        sys.exit()
+        
     
     return results, source_and_price_and_link_and_title, source_and_price
 
@@ -116,7 +149,7 @@ def apply_filters_to_source_price_link(source_price_link_title, target_price, bl
     
     for source, price, link,title in source_price_link_title:
         trigger_activated=False
-        if price < 0.4*target_price:
+        if price < too_good_to_be_true*target_price or price > target_price:
             continue
             
         trigger_activated = False
@@ -147,7 +180,7 @@ def target_items(search_results_data, names_and_prices_filtered):
         
         if sum([price < target_price for price in result_prices[:3]])>=2:
             #require 2 of the top 3 prices to be below 
-            return_list.append([name_price[0], name_price[1], source_price_link_title[:5]])
+            return_list.append([name_price[0], name_price[1], source_price_link_title[:num_results_shown]])
         else:
             pass
         
@@ -167,20 +200,20 @@ def generate_html_string(best_items):
 def user_function():
     sg.popup("Please download the html code and THEN click ok", keep_on_top=True)
     source_html_code = get_html_code()
-    products, product_names, names_prices = get_products_and_product_names_and_names_prices(source_html_code=source_html_code)
+    products, product_names, names_prices, names_to_amz_link = get_products_and_product_names_and_names_prices(source_html_code=source_html_code)
     
-    names_prices_filtered = [x for x in names_prices if "-" not in x[1]] #remove negative prices
+    names_prices_filtered = [x for x in names_prices if "-" not in x[1] and x[1]!="N/A"]
 
-    names_prices_filtered = [(x[0], get_price(x[1])) for x in names_prices_filtered] #remove currency symbols
+    names_prices_filtered = [(x[0], get_price(x[1])) for x in names_prices_filtered]
 
     res=[]
     i=0
     import time
     for name, price in names_prices_filtered:
         i+=1
-        res.append(search_shopping(name))
+        res.append(search_shopping(name, search_param))
         sg.one_line_progress_meter('One Line Meter Example', i + 1, len(names_prices_filtered))
-        time.sleep(throttle_rate)
+        time.sleep(1)
     res = [x for x in res if x !=None] #remove search results where we had no results
     names_where_search_worked = set([res[j][0]["search_parameters"]["q"] for j in range(len(res))]) #get names where search results worked, so we can trim the name and price data
     names_prices_filtered = [x for x in names_prices_filtered if x[0] in names_where_search_worked] #i.e., only look at the results where our search had results
@@ -198,7 +231,17 @@ def user_function():
 
     f.write(message)
     f.close()
-    webbrowser.open(f.name)
+
+    import platform
+    if platform.system() == "Windows":
+        webbrowser.open(f.name)
+    elif platform.system() == "Darwin":
+        import subprocess
+        subprocess.call(('open', f.name))
+    else:
+        sg.popup("Oops, we only support Mac and Windows")
+        import sys
+        sys.exit()
     
 if __name__ == "__main__":
     user_function()
